Module: Couchbase
- Defined in:
- lib/couchbase.rb,
lib/couchbase/view.rb,
lib/couchbase/async.rb,
lib/couchbase/error.rb,
lib/couchbase/utils.rb,
lib/couchbase/bucket.rb,
lib/couchbase/result.rb,
lib/couchbase/cluster.rb,
lib/couchbase/version.rb,
lib/couchbase/view_row.rb,
lib/couchbase/constants.rb,
lib/couchbase/operations.rb,
lib/couchbase/transcoder.rb,
lib/couchbase/async/queue.rb,
lib/couchbase/jruby/future.rb,
lib/couchbase/async/callback.rb,
lib/couchbase/jruby/couchbase_client.rb
Overview
- Author
Couchbase [email protected]
- Copyright
2011-2012 Couchbase, Inc.
- License
Apache License, Version 2.0
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Defined Under Namespace
Modules: Async, Constants, Error, Jruby, Operations, Transcoder Classes: Bucket, Cluster, DesignDoc, Result, Utils, View, ViewRow
Constant Summary collapse
- VERSION =
'0.1.0'- @@bucket =
Atomic.new(nil)
Class Attribute Summary collapse
-
.connection_options ⇒ Hash, String
Default connection options.
Class Method Summary collapse
-
.bucket ⇒ Bucket
The connection instance for current thread.
-
.bucket=(connection) ⇒ Bucket
Set a connection instance for current thread.
-
.connect(*options) ⇒ Bucket
(also: new)
The method
connectinitializes new Bucket instance with all arguments passed. - .connected? ⇒ Boolean
- .disconnect ⇒ Object
Class Attribute Details
.connection_options ⇒ Hash, String
Default connection options
83 84 85 |
# File 'lib/couchbase.rb', line 83 def @connection_options end |
Class Method Details
.bucket ⇒ Bucket
The connection instance for current thread
95 96 97 98 99 100 |
# File 'lib/couchbase.rb', line 95 def bucket if !connected? connect() end @@bucket.value end |
.bucket=(connection) ⇒ Bucket
Set a connection instance for current thread
107 108 109 |
# File 'lib/couchbase.rb', line 107 def bucket=(connection) @@bucket.update { |bucket| bucket = connection } end |
.connect(*options) ⇒ Bucket Also known as: new
The method connect initializes new Bucket instance with all arguments passed.
67 68 69 70 71 |
# File 'lib/couchbase.rb', line 67 def connect(*) disconnect @@bucket.update { |bucket| bucket ||= Bucket.new(*(.flatten)) } @@bucket.value end |
.connected? ⇒ Boolean
111 112 113 |
# File 'lib/couchbase.rb', line 111 def connected? !!@@bucket.value end |
.disconnect ⇒ Object
115 116 117 118 |
# File 'lib/couchbase.rb', line 115 def disconnect @@bucket.value.disconnect if connected? @@bucket = Atomic.new(nil) end |